package com.example.cs_ayetstudios_ad

import io.flutter.Log;
import android.app.Activity
import androidx.annotation.NonNull
import com.ayetstudios.publishersdk.AyetSdk
import com.ayetstudios.publishersdk.interfaces.UserBalanceCallback
import com.ayetstudios.publishersdk.interfaces.RewardedVideoCallbackHandler
import com.ayetstudios.publishersdk.messages.SdkUserBalance
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result


/** CsAyetstudiosAdPlugin */
class CsAyetstudiosAdPlugin: FlutterPlugin, MethodCallHandler, ActivityAware {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel : MethodChannel
  var activity: Activity? = null

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "cs_ayetstudios_android");
    channel.setMethodCallHandler(this);
  }

  fun OnMethodCallHandler(method: String, args: Map<String, Any>?) {
    try {
      activity?.runOnUiThread(Runnable { channel.invokeMethod(method!!, args) });
    } catch (e: Exception) {
      Log.e("flutter_ayetstudios", "Error $e");
    }
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    if (call.method == "init") {
      val uid: String = call.argument<String>("uid") ?: return;
      val appKey: String = call.argument<String>("appKey") ?: return;
      AyetSdk.init(activity?.application, uid, object : UserBalanceCallback {
        override fun userBalanceChanged(sdkUserBalance: SdkUserBalance) {
          OnMethodCallHandler("userBalanceChanged", mapOf("availableBalance" to sdkUserBalance.availableBalance));
        }

        override fun userBalanceInitialized(sdkUserBalance: SdkUserBalance) {
          val argsMap = mapOf("availableBalance" to sdkUserBalance.availableBalance, "spentBalance" to sdkUserBalance.spentBalance, "pendingBalance" to sdkUserBalance.pendingBalance);
          OnMethodCallHandler("initializationSuccess", argsMap);
        }

        override fun initializationFailed() {
          OnMethodCallHandler("initializationFailed", null);
        }
      }, appKey);
    } else if (call.method == "showOfferwallAd") {
      AyetSdk.getRewardedVideoCurrencyAmount();
      val adslotName: String = call.argument<String>("name") ?: return;
      AyetSdk.showOfferwall(activity?.application, adslotName);
    } else if (call.method == "showVideoAd") {
      val adslotName: String = call.argument<String>("name") ?: return;
      AyetSdk.showVideoAd(activity?.application, adslotName, AyetSdk.FLAG_DEFAULT, object : RewardedVideoCallbackHandler {
        override fun aborted(){
          OnMethodCallHandler("videoAborted", null);
        }

        override fun completed(amount: Int){
          OnMethodCallHandler("videoCompleted", mapOf("amount" to amount));
        }

        override fun nofill() {
          OnMethodCallHandler("videoNofill", null);
        }

        override fun finished(){
          OnMethodCallHandler("videoFinished", null);
        }

        override fun willBeShown(){
          OnMethodCallHandler("videoWillBeShown", null);
        }
      });
    } else if (call.method == "getAvailableBalance") {
      val balance = AyetSdk.getAvailableBalance(activity?.application);
      result.success(balance);
    } else if (call.method == "getSpentBalance") {
      val balance = AyetSdk.getSpentBalance(activity?.application);
      result.success(balance);
    } else if (call.method == "getPendingBalance") {
      val balance = AyetSdk.getPendingBalance(activity?.application);
      result.success(balance);
    } else {
      result.notImplemented();
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null);
  }

  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
    activity = binding.activity;
  }

  override fun onDetachedFromActivityForConfigChanges() {

  }

  override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
    activity = binding.activity;
  }

  override fun onDetachedFromActivity() {

  }


}
